Drink Up! 15 Good Ideas for Beer and Wine — The Kitchn's Best of 2014 | The Kitchn
Description: As we're getting ready to raise a glass to the new year, we figure it's a perfect time to look back at all the great beer and wine ideas and information we shared in 2014. Whether you prefer a crisp white, a full-bodied red, or a hoppy IPA, we can help you become a more informed (and satisfied) drinker.

# Drink Up! 15 Good Ideas for Beer and Wine

The Kitchn's Best of 2014

Why Chilling Your Beer Glass Isn't a Waste of Time

As we're getting ready to raise a glass to the new year, we figure it's a perfect time to look back at all the great beer and wine ideas and information we shared in 2014.

Whether you prefer a crisp white, a full-bodied red, or a hoppy IPA, we can help you become a more informed (and satisfied) drinker.

### Give Me a Beer!

- Why Chilling Your Beer Glass Isn't a Waste of Time
- 2-Ingredient Beer Cocktail Recipe: The Bloody Beer
- 10 Words to Know When Talking About Beer
- Video: The Best Way to Pour a Beer for Perfect Foam
- Yes! Here Are 6 Gluten-Free Beers That Don't Suck
- 5 Tips for Discovering Great Beer While Traveling
- ABV, IBU, SRM—OMG! Decoding 3 Common Beer Acronyms

### Pour Me a Glass of Wine

- 5 Types of Wine to Bring to a Party When You Have No Idea What's For Dinner
- How to Open a Bottle of Wine Using a Wine Key Corkscrew
- Why I Always Have a Box of Wine in My Refrigerator
- 6 Tips for Pairing Wine With Vegetables
- 10 Words to Know When Buying White Wine
- 10 Words to Know When Buying Red Wine
- 6 Tips for Hosting a Wine Tasting Party
- The Best Way to Preserve an Open Bottle of Wine

* * *

### Welcome to The Kitchn's Best of 2014 roundup!

From December 22 through January 4 we are rounding up our favorite (and your favorite) posts from the past year. Happy Holidays!

### More posts in this series

###### The Kitchn's Best of 2014

Previous
18 Things We Learned About Coffee in 2014
Next
10 Projects for a Happier Kitchen

(Image credits: Casey Barber; Rebecca Blumhagen; Jayme Henderson; Emma Christensen; Faith Durand; Jill Silverman Hough)

## Faith’s Daily Find

1. Ethiopian Hand Towels from Creative Women
2. FIKA Chocolate-Covered Pills
3. Champagne Flutes from Govino

See more

### Around the Web